@@ -6,16 +6,18 @@ from contextlib import ContextDecorator
 
 from IPython.display import display
 
+from . import _syntax
 from .widgets import Widgets
 from .navigation import Navigation
 from .settings import Settings
 from .notes import Notes
 from .export_html import _HhtmlExporter
 from .slide import _build_slide
-from ..formatters import XTML
-from ..xmd import _special_funcs, _md_extensions, error, fmt, get_slides_instance, resolve_included_files
+from ..formatters import XTML, htmlize
+from ..xmd import error, fmt, get_slides_instance, resolve_included_files, _matched_vars
 from ..utils import _css_docstring
 
+
 class BaseSlides:
     def __init__(self):
         self._uid = f'{self.__class__.__name__}-{id(self)}' # Unique ID for this instance to have CSS, should be before settings
@@ -55,173 +57,17 @@ class BaseSlides:
     @property
     def css_styles(self):
         """CSS styles for markdown or `styled` command."""
-        return XTML(self.parse('''
-        Use any or combinations of these styles in css_class argument of writing functions:
-                               
-        | css_class         | Formatting Style                                                                    
-        |:------------------|:---------------------------------------------------------
-         `text-[value]`     | [value] should be one of tiny, small, big, large, huge.
-         `align-[value]`    | [value] should be one of center, left, right.
-         `rtl`              | اردو،  فارسی، عربی،  ۔۔۔ {: .rtl}
-         `info`             | Blue text. Icon ℹ️  for note-info class. {: .info}
-         `tip`              | Blue Text. Icon💡 for note-tip class. {: .tip}
-         `warning`          | Orange Text. Icon ⚠️ for note-warning class. {: .warning}
-         `success`          | Green text. Icon ✅ for note-success class. {: .success}
-         `error`            | Red Text. Icon⚡ for note-error class. {: .error}
-         `note`             | Text with note icon, can combine other classes as shown above. {: .note}
-         `export-only`      | Hidden on main slides, but will appear in exported slides.
-         `jupyter-only`     | Hidden on exported slides, but will appear on main slides.
-         `block`            | Block of text/objects {: .block}
-         `block-[color]`    | Block of text/objects with specific background color from <br> red, green, blue, yellow, cyan, magenta and gray.
-         `raw-text`         | Text will be shown as printed style. {: .raw-text}
-         `zoom-self`        | Zooms object on hover, when Zoom is enabled. {: .zoom-self}
-         `zoom-child`       | Zooms child object on hover, when Zoom is enabled.
-         `no-zoom`          | Disables zoom on object when it is child of 'zoom-child'.
-        
-        Besides these CSS classes, you always have `Slide.set_css`, `Slides.html('style',...)` functions at your disposal.
-        ''',returns = True))
+        return XTML(htmlize(_syntax.css_styles))
 
-    @property
-    def xmd_syntax(self):
-        "Special syntax for markdown."
-        with self._hold_running():
-            return XTML(self.parse(textwrap.dedent(rf'''
-        **Extended Markdown**{{.text-large}}
-                                               
-        Extended syntax for markdown is constructed to support almost full presentation from Markdown.
-        
-        **Slides-specific syntax**{{.text-big}}
-        
-        Notes
-        : alert`notes\`This is slide notes\``  to add notes to current slide
-        
-        Slides & Frames Separators
-        : Triple dashes `---` is used to split text in slides inside markdown content of `Slides.build` function or markdown file.
-        Double dashes `--` is used to split text in frames. Alongwith this `%++` can be used to increment text on framed slide.
-        
-        Citations
-        : - alert`cite\`key1,key2\`` / alert`\@key1,\@key2` to add citation to current slide. citations are automatically added in suitable place and should be set once using `Slides.set_citations` function (or see below).
-        - With citations mode set as 'footnote', you can add alert`refs\`ncol_refs\`` to add citations anywhere on slide. If `ncol_refs` is not given, it will be picked from layout settings.
-        - Force a citation to be shown inline by appending a ! even in footnote mode, such as alert`\@key!`.
-        - In the synced markdown file (also its included files) through `Slides.sync_with_file`, you can add citations with block sytnax:                             
-        hl["markdown"]`
-        \`\`\`citations [inline or footnote]
-        \@key1: Saboor et. al., 2025
-        \@key2: A citations can span multiple lines, but key should start on new line
-        \`\`\``
-        
-        Sections & TOC
-        : alert`section\`content\`` to add a section that will appear in the table of contents.
-        alert`toc\`Table of content header text\`` to add a table of contents. See `Slides.docs()` for creating a `TOC` accompanied by section summary.
-        
-        **General syntax**{{.text-big}}
-        
-        - Use alert`fa\`icon_name\`` to add FontAwesome icons, e.g. fa\\`arrow-right\\` → fa`arrow-right`, fa\\`check\\` → fa`check`, fa\\`info-circle\\` → fa`info-circle` etc.
-        - Use syntax \`<link:[unique id here]:origin label>\` and \`<link:[unique id here same as origin]:target [back_label,optional]>\` to jump between slides. See `Slides.link` for more details.
-        - Variables can be shown as widgets or replaced with their HTML value (if no other formatting given) using alert`\%{{variable}}` (or legacy alert`\`{{variable}}\``) 
-            (should be single curly braces pair wrapped by backticks after other formattings done) syntax. If a format_spec/conversion is provided like
-            alert`\%{{variable:format_spec}}` or alert`\%{{variable!conversion}}`, that will take preference.
-        - A special formatting alert`\%{{variable:nb}}` is added (`version >= 4.5`) to display objects inside markdown as they are displayed in a Notebook cell.
-            Custom objects serialized with `Slides.serializer` or serialized by `ipyslides` should be displayed without `:nb` whenever possible to appear in correct place in all contexts. e.g.
-            a matplotlib's figure `fig` as shown in `\%{{fig:nb}}` will only capture text representation inplace and actual figure will be shown at end, while `\%{{fig}}` will be shown exactly in place.
-        
-        ::: note-tip
-            - Variables are automatically updated in markdown when changed in Notebook for slides built purely from markdown.
-                - You can also use hl`Slide[number,].rebuild(**kwargs)` to force update variables if some error happens. This is useful for setting unique values of a variable on each slide.
-                - Markdown enclosed in hl`fmt(content, **vars)` will not expose encapsulated `vars` for updates later, like static stuff but useful inside python scripts to pick local scope variable.
-                - In summary, variables are resolved by scope in the prefrence `rebuild > __main__`. Outer scope variables are overwritter by inner scope variables.
-            - Use unique variable names on each slide to avoid accidental overwriting during update.
-            - Varibales used as attributes like `\%{{var.attr}}` and indexing like `\%{{var[0]}}` / `\%{{var["key"]}}` will be update only if `var` itself is changed.
-
-        ::: note-warning
-            alert`\%{{variable:nb}}` breaks the DOM flow, e.g. if you use it inside heading, you will see two headings above and below it with splitted text. Its fine to use at end or start or inside paragraph.                                    
-        
-        ::: note-info
-            - Widgets behave same with or without `:nb` format spec. 
-            - Formatting is done using `str.format` method, so f-string like literal expressions are not supported, but you don't need to supply variables, just enclose text in `Slides.fmt`.
-            - Variables are substituted from top level scope (Notebook's hl`locals()` / hl`globals()`). To use variables from a nested scope, use `Slides.fmt`.
-        
-        - Cells in markdown table can be spanned to multiple rows/columns by attributes | cell text \{{: rowspan="2" colspan="1"}}| inside a cell, should be a space bewteen text and attributes.
-        - Escape a backtick with \\, i.e. alert`\\\` → \``. In Python >=3.12, you need to make escape strings raw, including the use of $ \LaTeX $ and re module.
-        - alert`include\`markdown_file.md[optional list slicing to pick lines from file such as [2:5], [10:]]\`` to include a file in markdown format. These files are watched for eidts if included in synced markdown file via `Slides.sync_with_file`.
-        - Inline columns/rows can be added by using alert`stack\`Column A || Column B\`` sytnax. You can escape pipe `|` with `\|` to use it as text inside stack. See at end how to nest such stacking.
-        - Block multicolumns are made using follwong syntax, column separator is triple plus `+++`:
-        
-        ```md-left
-            ```multicol 2 3 .block-blue
-                ```md-after
-                ## Column A
-                ```
-            +++
-                ## Column B
-                ```multicol .block-red
-                **Nested Column A**{{: .block-green}}
-                +++
-                **Nested Column B**{{: .block-yellow}}
-                ```
-            ```
-        ```
-        
-        - Definition list syntax:
-        ```md-left
-        Item 1 Header
-        : Item 1 details
-
-        Item 1 Header
-        : Item 1 details
-        ```
-        
-        - `md-[left,right,before,after]` and `multicol` support nesting via proper indentation, but it may be broken by display contexts. 
-        - Code blocks syntax highlighting. (there is an inline highlight syntax as well alert`hl\`code\``)
-        
-        ```python
-        print('Hello, I was highlighted from a code block!')
-        ```     
-                                                                              
-        - A whole block of markdown can be CSS-classed using syntax
-        ```md-left -c
-        ::: block-yellow
-            Some **bold text**
-        ```
-            
-        ::: note 
-            Above block syntax is enabled using [customblocks](https://github.com/vokimon/markdown-customblocks) 
-            which is added by default and can be used to build nested html blocks.
-            
-        ::: block-red 
-            - You can use `Slides.extender` to extend additional syntax using Markdown extensions such as 
-                [markdown extensions](https://python-markdown.github.io/extensions/) and 
-                [PyMdown-Extensions](https://facelessuser.github.io/pymdown-extensions/).
-            - These markdown extensions are inluded by default hl`{_md_extensions}`.
-            - You can serialize custom python objects to HTML using `Slides.serializer` function. Having a 
-                `__format__` method in your class enables to use {{obj}} syntax in python formatting and \%{{obj}} in extended Markdown.
-        
-        - Upto 4 level nesting is parsed using (level + 1) number of alert`/` (at least two) within backticks in functions given below. 
-        ```md-left -c
-        stack[(6,4),css_class="block-blue"]`////
-            This always parse markdown in `returns=True` mode and is equivalent to markdown customblocks. ||
-            stack[css_class="info"]`/// B || A
-                stack[vertical=True]`// C ||
-                    stack[css_class="block-red"]` D || E ` 
-                //` 
-            ///` 
-        ////`
-        ```
-        
-        - Other options (that can also take extra args [python code as strings] as alert`func[arg1,x=2,y=A]\`arg0\``) include:
-        ''') + '\n' + ',\n'.join(rf'    - alert`{k}`\\`{v}\\`' for k,v in _special_funcs.items()),
-        returns = True
-        ))
-    
     @property
     def css_syntax(self):
         "CSS syntax for use in Slide.set_css, Slides.html('style', ...) etc."
         return XTML(_css_docstring)
    
     def get_source(self, title = 'Source Code', **kwargs):
-        "Return source code of all slides except created as frames with python code. kwargs are passed to `Slides.highlight`."
+        "Return source code of all slides except created as frames with python code. kwargs are passed to `Slides.code`."
         sources = []
-        for slide in self.all_slides:
+        for slide in self[:]:
             if slide._source['text']:
                 kwargs['name'] = f'{slide._source["language"].title()}: Slide {slide.index}' #override name
                 sources.append(slide.get_source(**kwargs))
@@ -252,16 +98,16 @@ class BaseSlides:
             with self.widgets._tmp_out:
                 display(*objs)
         
-    def _from_markdown(self, start, /, content, synced=False):
+    def _from_markdown(self, start, /, content, synced=False, _vars=None):
         "Sames as `Slides.build` used as a function."
         if self.this:
             raise RuntimeError('Creating new slides under an already running slide context is not allowed!')
         
-        if not isinstance(content, (str,fmt)): #check path later or it will throw error
-            raise TypeError(f"content expects a makrdown text block or fmt, got {content!r}")
+        if not isinstance(content, str): #check path later or it will throw error
+            raise TypeError(f"content expects a makrdown string, got {content!r}")
         
-        content, fmt_kws = fmt._astuple(content) # fmt used on top level, or string means no keywords
         content = re.split(r'^\s*EOF\s*$',content, flags = re.MULTILINE)[0]
+        md_kws = _vars or {} # given from build function call
 
         if synced:
             content = self._process_citations(content)
@@ -273,31 +119,34 @@ class BaseSlides:
         
         chunks = _parse_markdown_text(content)
         handles = self.create(range(start, start + len(chunks))) # create slides faster or return older
+        mdvars  = [{k:v for k,v in md_kws.items() if k in _matched_vars(chunk)} for chunk in chunks] # vars used in each chunk
 
-        for i,chunk in enumerate(chunks):
+        for chunk, hdl, mvs in zip(chunks, handles, mdvars):
             # Must run under this function to create frames with two dashes (--) and update only if things/variables change
-            if any(['Out-Sync' in handles[i]._css_class, chunk != handles[i]._markdown]):
+            if any(['Out-Sync' in hdl._css_class, chunk != hdl._markdown, mvs != hdl._md_vars]):
                 with self._loading_splash(self.widgets.buttons.refresh): # Hold and disable other refresh button while doing it
-                    self._slide(f'{i + start} -m', chunk, fmt_kws=fmt_kws, synced=synced)
+                    hdl._md_vars = mvs # set corresponding vars to access while building slide
+                    self._slide(f'{hdl.number} -m', chunk)
             else: # when slide is not built, scroll buttons still need an update to point to correct button
-                self._slides_per_cell.append(handles[i])
+                self._slides_per_cell.append(hdl)
         
         # Return refrence to slides for quick update
         return handles
     
     def _process_citations(self, content):
-        match1, *others = re.findall(r'```citations(.*?)\n```', content, flags= re.DOTALL | re.MULTILINE)
+        match1, *others = re.findall(r'^```citations.*?^```|^:::\s*citations.*?(?=^:::|\Z|^\S)', content, flags= re.DOTALL | re.MULTILINE)
         if others:
-            raise ValueError(f"Only a single block of citations is parsed, found {len(others) + 1} blocks")
-            
-        content = content.replace(f'```citations{match1}\n```','') # clean up
+            raise ValueError(f"Only a single block of citations is parsed, found {len(others) + 1} blocks\n{(match1, *others)}")
+        
+        content = content.replace(match1, '') # clean up
         if getattr(self,'_bib_md','') != match1:
             self._bib_md = match1 # set for next test
-
-            mode, refs = [line.strip() for line in match1.split('\n',1)] # should be ```citations mode and then below
+            head, refs = match1.split('\n', 1) # split into mode and references
+            mode = head[3:].replace('citations','',1).strip() # remove name citations
+            refs = refs.rstrip('` ') # remove trailing ` or space, 
             if not mode:
                 mode = self._cite_mode # keep same
-            self.set_citations(refs, mode=mode)
+            self.set_citations(textwrap.dedent(refs), mode=mode)
         return content
     
     def sync_with_file(self, start_slide_number, /, path, interval=500):
@@ -307,7 +156,7 @@ class BaseSlides:
         The variables inserted in file content are used from top scope.
 
         You can add files inside linked file using include\\`file_path.md\\` syntax, which are also watched for changes.
-        This helps modularity of content, and even you can link a citation file in markdown format as shown below. Read more in `Slides.xmd_syntax` about it.
+        This helps modularity of content, and even you can link a citation file in markdown format as shown below. Read more in `Slides.xmd.syntax` about it.
 
         ```markdown
          ```citations footnote
@@ -376,35 +225,36 @@ class BaseSlides:
         else:
             print("There was no markdown file linked to sync!")
     
-    def build_(self, content = None):
+    def build_(self, content = None, /, **vars):
         "Same as `build` but no slide number required inside Python file!"
         if self.inside_jupyter_notebook(self.build_):
             raise Exception("Notebook-only function executed in another context. Use build without _ in Notebook!")
-        return self.build(self._next_number, content=content)
+        return self.build(self._next_number, content, **vars)
 
     class build(ContextDecorator):
         r"""Build slides with a single unified command in three ways:
         
-        1. hl`slides.build(number, callable)` to create a slide from a `callable(slide)` immediately, e.g. hl`lambda s: slides.write(1,2,3)` or as a decorator.
+        1. code`slides.build(number, callable)` to create a slide from a `callable(slide)` immediately, e.g. code`lambda s: slides.write(1,2,3)` or as a decorator.
             - Docstring of callable (if any) is parsed as markdown before calling function.
-        2. hl`with slides.build(number):` creates single slide. Equivalent to hl`%%slide number` magic.
-            - Use hl`fsep()` from top import or hl`Slides.fsep()` to split content into frames.
-            - Use hl`for item in fsep.iter(iterable):` block to automatically add frame separator.
-            - Use hl`fsep(True)` / hl`fsep.iter(...,stack=True)` to join content of frames incrementally.
-        3. hl`slides.build(number, str | fmt)` creates many slides with markdown content. Equivalent to hl`%%slide number -m` magic in case of one slide.
-            - Frames separator is double dashes `--` and slides separator is triple dashes `---`. Same applies to hl`Slides.sync_with_file` too.
+        2. code`with slides.build(number):` creates single slide. Equivalent to code`%%slide number` magic.
+            - Use code`fsep()` from top import or code`Slides.fsep()` to split content into frames.
+            - Use code`for item in fsep.iter(iterable):` block to automatically add frame separator.
+            - Use code`fsep(True)` / code`fsep.iter(...,stack=True)` to join content of frames incrementally.
+        3. code`slides.build(number, str, **vars)` creates many slides with markdown content. Equivalent to code`%%slide number -m` magic in case of one slide.
+            - Frames separator is double dashes `--` and slides separator is triple dashes `---`. Same applies to code`Slides.sync_with_file` too.
             - Use `%++` to join content of frames incrementally.
             - Markdown `multicol` before `--` creates incremental columns if `%++` is provided.
-            - See `slides.xmd_syntax` for extended markdown usage.
+            - See `slides.xmd.syntax` for extended markdown usage.
             - To debug markdown content, use EOF on its own line to keep editing and clearing errors. Same applies to `Slides.sync_with_file` too.
-            - In case of str input, varaiables such as \%{var} can be updated by creating/updating `var` in notebook.
-            - In case of `fmt(str, **kwargs)`, varaiables are picked from `kwargs` or local scope and can't be changed later. Useful in python scripts.
+            - Variables such as \%{var} can be provided in `**vars` (or left during build) and later updated in notebook using `rebuild` method on slide handle or overall slides.
+            - If an f-string is provided, variables in f-string are resolved eagerly and never get updated on rebuild including lazy ones provided by `Slides.esc`.
+        
         
-
         ::: note-tip
             - In all cases, `number` could be used as `-1`.
-            - Use yoffet`integer in px` in markdown or hl`Slides.this.yoffset(integer)` to make all frames align vertically to avoid jumps in increments.
-            - You can use hl`build_(...)` (with underscore at end) in python file instead of hl`build(-1,...)`.
+            - Use yoffet`integer in percent` in markdown or code`Slides.this.yoffset(integer)` to make all frames align vertically to avoid jumps in increments.
+            - You can use code`build_(...)` (with underscore at end) in python file instead of code`build(-1,...)`.
+            - `**vars` are ignored silently if `build` is used as contextmanager or decorator.
         """
         @property
         def _app(self):
@@ -413,7 +263,7 @@ class BaseSlides:
                 kls._slides = get_slides_instance()
             return kls._slides
         
-        def __new__(cls, slide_number, /, content = None):
+        def __new__(cls, slide_number, content = None, /, **vars):
             self = super().__new__(cls) # instance
             self._snumber = self._app._fix_slide_number(slide_number)
             
@@ -421,20 +271,24 @@ class BaseSlides:
                 if (content is not None) and any([code.startswith(c) for c in ('@', 'with')]):
                     raise ValueError("content should be None while using as decorator or contextmanager!")
                 
-                if isinstance(content, (str,fmt)) and not code.startswith('with'): 
-                    return self._app._from_markdown(self._snumber, content)
+                # using fmt is tempting to delegate vars automatically but it raises error if var not found, 
+                # which is against whole philosophy of lazy evaluation and rebuild.
+                # Also, using vars in decorator mode for function docstring is a bad idea as it
+                # will be evaluated only once and never updated on rebuild, also it is not supported by python syntax.
+                if isinstance(content, str) and not code.startswith('with'): 
+                    return self._app._from_markdown(self._snumber, content, _vars = vars)
 
                 if callable(content) and not code.startswith('with'):
                     with _build_slide(self._app, self._snumber) as s: 
                         s._set_source(self._app.code.from_source(content).raw,'python') 
                         if (doc := getattr(content, '__doc__', None)):
-                            self._app.parse(doc, returns=False)
+                            self._app.xmd(doc, returns=False)
                         content(s) # call directly, set code before to make avaiable in function
                 
                     return s
             
             if content is not None:
-                raise ValueError(f"content should be None, str,fmt, or callable. got {type(content)}")
+                raise ValueError(f"content should be None, str, or callable. got {type(content)}")
 
             return self # context manager
 
@@ -453,7 +307,7 @@ class BaseSlides:
             return f"<ContextDecorator build at {hex(id(self))}>"
         
         def __call__(self, func):
-            "Use @build decorator. func accepts slide as arguemnt."
+            "Use @build decorator. func accepts slide as argument."
             type(self)(self._snumber, func)
             
 
@@ -467,7 +321,7 @@ class BaseSlides:
         "Create presentation from docs of IPySlides."
         self.close_view() # Close any previous view to speed up loading 10x faster on average
         self.clear() # Clear previous content
-        self.create(range(25)) # Create slides faster
+        self.create(range(31)) # Create slides faster
         
         from ..core import Slides
 
@@ -478,7 +332,7 @@ class BaseSlides:
             self.this.set_bg_image(self.get_logo(),0.25, filter='blur(10px)', contain=True)
             self.write(f'## IPySlides {self.version} Documentation\n### Creating slides with IPySlides')
             self.center(self.fmt('''
-                alert`Abdul Saboor`sup`1`
+                alert`Abdul Saboor` ^`1`
                                  
                 today``
                 {.text-small}
@@ -486,10 +340,10 @@ class BaseSlides:
                 %{logo}
                                  
                 ::: text-box
-                    sup`1`My University is somewhere in the middle of nowhere
+                    ^`1`My University is somewhere in the middle of nowhere
                 ''', logo = self.get_logo("4em"))).display()
         
-        self.build(-1, self.fmt('''
+        self.build(-1, '''
             ```md-after
                 section`Introduction` 
                 ```multicol .block-green
@@ -499,7 +353,7 @@ class BaseSlides:
                 Oh we can use inline columns stack`Column A || Column B` here and what not!
                 %{btn}
                 ```
-            ```''', btn = self.draw_button))
+            ```''', btn = self.draw_button)
             
         with self.build(-1):
             self.write('# Main App')
@@ -522,18 +376,18 @@ class BaseSlides:
             self.write('''
                 ## Important Methods on Slide
                 ::: note-warning
-                    Use slide handle or `Slides[number,]` to apply these methods becuase index can change on new builds.
+                    - Use slide handle or `Slides[number,]` to apply these methods becuase index can change on new builds.
+                    - Use `Slides[start:stop:step]` to apply operations on many slides at once such as code`Slides[2:5].vars.update(...)`.
             ''')
-            self.doc(self[0], members='yoffset set_animation set_bg_image update_display get_source show set_css'.split(), itself = False).display()
+            self.doc(self[0], members='yoffset vars set_animation set_bg_image update_display get_source show set_css'.split(), itself = False).display()
             self.css_syntax.display()
         
-        with self.build(-1):
-            self.xmd_syntax.display()
+        self.build(-1, re.sub(r'^---\s*$', '---\n## Extended Markdown' ,_syntax.xmd_syntax, flags=re.MULTILINE))
             
         with self.build(-1):
             self.write('## Adding Content')
             self.write('Besides functions below, you can add content to slides with `%%xmd`,`%xmd` as well.\n{.note .info}')
-            self.write(self.doc(self.write,'Slides'), [self.doc(self.parse,'Slides'),self.doc(self.as_html,'Slides'),self.doc(self.html,'Slides')])
+            self.write(self.doc(self.write,'Slides'), [self.doc(self.xmd,'Slides'),self.doc(self.as_html,'Slides'),self.doc(self.as_html_widget,'Slides'),self.doc(self.html,'Slides')])
         
         with self.build(-1):
             self.write('## Adding Speaker Notes')
@@ -544,7 +398,7 @@ class BaseSlides:
         with self.build(-1):
             self.write('## Displaying Source Code')
             self.write('In markdown, the block `md-[before,after,left,right] [-c]` parses and displays source as well.')
-            self.doc(self.code,'Slides.code', members = True, itself = False).display()
+            self.doc(self.code,'Slides', members = True, itself = True).display()
         
         self.build(-1, r'section`//Layout and color["yellow","black"]`Theme` Settings//` toc`### Contents`')
         
@@ -561,8 +415,8 @@ class BaseSlides:
             self.doc(self.alt,'Slides').display()
             
             members = sorted((
-                'AnimationSlider alert block bokeh2html bullets styled fmt color details doc '
-                'today error zoomable highlight html iframe image frozen notify plt2html '
+                'AnimationSlider alert bokeh2html bullets esc styled fmt code color details doc '
+                'today error zoomable html iframe image frozen notify plt2html '
                 'raw set_dir sig stack table textbox suppress_output suppress_stdout svg vspace'
             ).split())
             self.doc(self, 'Slides', members = members, itself = False).display()
@@ -570,9 +424,9 @@ class BaseSlides:
         with self.build(-1):
             self.write(r'''
                 ## Citations and Sections
-                Use syntax alert`cite\`key\`` / alert`\@key` to add citations which should be already set by hl`Slides.set_citations(data, mode)` method.
+                Use syntax alert`cite\`key\`` / alert`\@key` to add citations which should be already set by code`Slides.set_citations(data, mode)` method.
                 Citations are written on suitable place according to given mode. Number of columns in citations are determined by 
-                hl`Slides.settings.layout(..., ncol_refs = int)`. @A
+                code`Slides.settings.layout(..., ncol_refs = int)`. @A
                        
                 Add sections in slides to separate content by alert`section\`text\``. Corresponding table of contents
                 can be added with alert`toc\`title\``.
@@ -586,8 +440,8 @@ class BaseSlides:
             with self.capture_content() as cap, self.code.context():
                 import time
 
-                @self.ei.interact(auto_update=False, grid_css = dict({'.out-main': dict(height='2em')},background='var(--bg2-color)'), date = False)  # self is Slides here
-                def update_time(date): 
+                @self.dl.interact(post_init = lambda self: self.set_css(dict({'.out-main': dict(height='2em')},background='var(--bg2-color)')), date = False, btn = self.dl.button())  # self is Slides here
+                def update_time(date, btn): 
                     local_time = time.localtime()
                     objs = ['Time: {3}:{4}:{5}'.format(*local_time)] # Print time in HH:MM:SS format
                     if date:
@@ -604,26 +458,26 @@ class BaseSlides:
                     self.notify(f'Notification at {time} form slide {slide.index} and frame {slide.indexf}', timeout=5)
             
             self.write(
-                [self.doc(self.ei.interact,'Slides.ei')], 
+                [self.doc(self.dl.interact,'ipyslides.dashlab')], 
                 [*cap.outputs, c, self.doc(self.on_load,'Slides')],
             )
     
-        self.build(-1, fmt("""
+        self.build(-1, """
         ```md-after -c
         stack[(3,7)]`//
         ## Content Styling
         You can **style**{.error} or **color["teal"]`colorize`** your *content*{: style="color:hotpink;"} and *color["hotpink","yellow"]`text`*.
-        Provide **CSS**{.info} for that using hl`Slides.html("style",...)` or use some of the available styles. 
+        Provide **CSS**{.info} for that using code`Slides.html("style",...)` or use some of the available styles. 
         See these **styles**{.success} with `Slides.css_styles` property as shown on right.
         || %{self.css_styles}
         //`     
         ```
-        """))
+        """, self=self)
         
-        self.build(-1, self.fmt('''
+        self.build(-1, '''
         ## Highlighting Code
         [pygments](https://pygments.org/) is used for syntax highlighting cite`A`.
-        You can **highlight**{.error} code using `highlight` function cite`B` or within markdown using code blocks enclosed with three backticks:
+        You can **highlight**{.error} code using `Slides.code` cite`B` or within markdown using named code blocks:
         ```python
         import ipyslides as isd
         ```
@@ -631,7 +485,7 @@ class BaseSlides:
         import React, { Component } from "react";
         ```
         Source code of slide can be embeded via variable too: %{self.this.source}
-        ''', self=self))
+        ''', self=self)
 
         
         with self.build(-1):
@@ -663,7 +517,7 @@ class BaseSlides:
             self.write(r'If you need to serialize your own or third party objects not serialized by this module, you can use `\@Slides.serializer.register` to serialize them to html.\n{.note .info}')
             self.doc(self.serializer,'Slides.serializer', members = True, itself = False).display()
             self.write('**You can also extend markdown syntax** using `markdown extensions`, ([See here](https://python-markdown.github.io/extensions/) and others to install, then use as below):')
-            self.doc(self.extender,'Slides.extender', members = True, itself = False).display()
+            self.doc(self.xmd.extensions,'Slides.xmd.extensions', members = True, itself = False).display()
         
         with self.build(-1):
             self.write(r'''
@@ -686,13 +540,14 @@ class BaseSlides:
                     btn = ipw.Button(description='Chevron-Down Icon',icon='chevrond')    
                     self.write(btn)
 
+            group = zip(self.icon.available[::2], self.icon.available[1::2]) # make 4 columns table
             self.write(['''
                 ## SVG Icons
                 Icons that apprear on buttons inslides (and their rotations) available to use in your slides as well
                 besides standard ipywidgets icons.
                 ''', *c.outputs, 'line`200`**Source code of this slide**',self.this.get_source()], 
-                self.table([(f'`{k}`', self.icon(k,color='crimson').svg) for k in self.icon.available],headers=['Name','Icon']),
-            widths=[2,1])
+                self.table([(f'`{j}`', self.icon(j,color='crimson').svg,f'`{k}`', self.icon(k,color='crimson').svg) for j, k in group],headers=['Name','Icon','Name','Icon']),
+            widths=[3,2])
                 
             
         with self.build_():
@@ -703,7 +558,7 @@ class BaseSlides:
                 - In Jupyter notebook, this will be updated to current slide number. 
                 - In python file, it stays same.
                 - You need to run cell twice if creating slides inside a for loop while using `-1`.
-                - Additionally, in python file, you can use `Slides.build_` instead of using `-1`.
+                - Additionally, in python file, you can use ` Slides.build_ ` instead of using `-1`.
                        
                 ::: note-warning
                     Some kernels may not support auto slide numbering inside notebook.
@@ -715,7 +570,6 @@ class BaseSlides:
     
 def _parse_markdown_text(text_block):
     "Parses a Markdown text block and returns text for title and each slide."
-    # user may used fmt
     lines = textwrap.dedent(text_block).splitlines() # Remove overall indentation
     breaks = [-1] # start, will add +1 next
     for i,line in enumerate(lines):
