@@ -29,7 +29,7 @@ slides = isd.Slides()
 ```
 ```python
 %%slide 2 -m 
-**Markdown here with extended options (see `slides.xmd_syntax` for info). Nested blocks are not supported**
+**Markdown here with extended options (see `slides.xmd.syntax` for info). Nested blocks are not supported**
  ```multicol 30 70 .success
  less content
  +++
@@ -48,16 +48,15 @@ with slides.build(-1):
 ```
 
 ```python
-slides.build(-1, slides.fmt('''
+slides.build(-1, r'''
 Markdown content can create many slides at once here!
-fmt can encapsulate varaiables like \%{var}.
-This is useful inside python scripts. Markdown not encapsulated
-by fmt can be used to update varaiables from notebook later.
-''',var="I am a variable"))
+Variables like \%{var} can be provided after content or left to be updated later in notebook.
+This is useful inside python scripts. 
+''',var="I am a variable")
 ```
 
 ```python
-slides # This displays slides if on the last line of cell, or use hl`slides.show()`.
+slides # This displays slides if on the last line of cell, or use code`slides.show()`.
 ```
 
 ::: note-info
@@ -67,8 +66,8 @@ slides # This displays slides if on the last line of cell, or use hl`slides.show
     - Use `Slides.docs` to see upto date documentation.
     - Use `Slides.demo` to create example slides.
     - Use  `Slides.sync_with_file` to live edit and update slides through a markdown file.
-    - Find special syntax to be used in markdown by `Slides.xmd_syntax`.
-    - Use `Slides.extender` to add [markdown extensions](https://python-markdown.github.io/extensions/). Also look at [PyMdown-Extensions](https://facelessuser.github.io/pymdown-extensions/).
+    - Find special syntax to be used in markdown by `Slides.xmd.syntax`.
+    - Use `Slides.xmd.extensions` to add [markdown extensions](https://python-markdown.github.io/extensions/). Also look at [PyMdown-Extensions](https://facelessuser.github.io/pymdown-extensions/).
 """
 
 _icons = {key: _Icon(key, color="var(--accent-color)") for key in _Icon.available}
@@ -92,7 +91,7 @@ key_maps = {
 
 key_combs = f"""
 | Shortcut                                    | Button                                            | Action                 | 
-|---------------------------------------------|---------------------------------------------------|------------------------|
+|:--------------------------------------------|---------------------------------------------------|:-----------------------|
 | {_key('&#9141;')}/{_key('▸')}               | {_icons["chevronr"]}                              | Move to next slide     |
 | {_key('Ctrl')} + {_key('&#9141;')}/{_key('◂')} | {_icons["chevronl"]}                           | Move to previous slide |
 | {_key('Ctrl')} + {_key('0')}/{_key('0')}    | {_icons['arrowbl']}/{_icons['arrowbr']}       | Jump to Star/End of slides |
