@@ -2,15 +2,74 @@
 
 import time, textwrap
 from contextlib import contextmanager, suppress
+from functools import wraps
 from IPython.display import display
 from IPython.utils.capture import RichOutput
 
 from . import styles
 from ..utils import XTML, html, _styled_css, _build_css
-from ..xmd import capture_content, _matched_vars
+from ..xmd import capture_content
 from ..formatters import _Output, widget_from_data
 from ._layout_css import background_css
+
+class Vars:
+    """Container for markdown slide variables, to see and update variables
+    set on a slide or a group of slides.
     
+    - `slides.s1.vars.update(name="New")` updates variable 'name' on slide 1 only
+    - `slides.s2.vars.pop('age')` removes variable 'age' from slide 2 only, so it is picked from notebook scope
+    - `slides.s3.vars.clear()` clears all variables set on slide 3 only, so they are picked from notebook scope
+    - `slides[:].vars.update(theme='dark')` updates variable 'theme' on all slides
+    - `slides[1:3].vars.pop('title')` removes variable 'title' from slide 1 and 2 only
+    - `slides[0].vars.scope` see variables with scope set on slide 0
+    """
+    def __init__(self, *slides):
+        self._slides = slides
+    
+    def __repr__(self):
+        scp = self.scope # could be tuple of dicts or single dict
+        scps = (scp,) if isinstance(scp, dict) else scp
+        head = "Scope       Vars\n=====       ====\n"
+        return head + str.join(f"\n-----       ----\n", 
+            ('\n'.join(f"{sc:<12}{value}" 
+            for sc, value in scp.items()) for scp in scps)
+        )
+    
+    @property
+    def scope(self):
+        "Returns variables info at different levels. 0: Slide, 1: Notebook scope, 2: Undefined."
+        scopes = tuple({
+            f'Slide{s.number}': tuple(s._md_vars), # only those set on slide
+            'Notebook': tuple(v for v in s._req_vars if v in s._app._nb_vars), # only for this slide out of all
+            'Undefined': tuple(v for v in s._req_vars if v not in s._app._nb_vars),
+        } for s in self._slides if s._has_vars) # only markdown slides have variables, no need to make empty dict
+        return scopes[0] if len(scopes) == 1 else scopes
+    
+    def update(self, **vars):
+        """Update variables on a slide or group of slides. Unsed variables are ignored silently.
+        
+        - `slides.s1.vars.update(name="New Name", age=30)` updates variables 'name' and 'age' on slide 1 only.
+        - `slides[:].vars.update(theme='dark')` updates variable 'theme' on all slides.
+        - `slides[1:3].vars.update(title="New Title")` updates variable 'title' on slide 1 and 2 only.
+        """
+        for s in self._slides:
+            s._md_vars.update({k:v for k,v in vars.items() if k in s._has_vars}) # only update required vars
+            s._rebuild(True if len(self._slides) == 1 else False) # go there only if single slide
+        
+    __call__ = update # allow calling directly like slide.vars(...)
+    
+    def pop(self, *vars):
+        "Remove variables from a slide or group of slides, so they are picked from higher scopes."
+        for s in self._slides:
+            for k in vars:
+                s._md_vars.pop(k, None) # avoid key error if not present
+            s._rebuild(True if len(self._slides) == 1 else False) # go there only if single slide
+    
+    def clear(self):
+        "Clear all variables from a slide or group of slides, so they are picked from higher scopes."
+        for s in self._slides:
+            s._md_vars.clear()
+            s._rebuild(True if len(self._slides) == 1 else False) # go there only if single slide
 
 class Slide:
     "Slide object, should not be instantiated directly by user."
@@ -26,8 +85,10 @@ class Slide:
         self._index = number if number == 0 else None # First slide should have index ready
         self._animation = None
         self._sec_id = f"s-{id(self)}" # should there alway wether a section or not
-        self._md_vars = {}
+        self._md_vars = {} # store variables set by build/rebuild on this slide
+        self._esc_vars = {} # store escaped variables for rebuilds form build content
         self._set_defaults()
+        self.vars = Vars(self) # to access variables info and update them
 
         if not self._contents: # show slide number hint there
             self.set_css({
@@ -53,7 +114,7 @@ class Slide:
         self._indexf = 0 # current frame index
         self._contents = [] # reset content to not be exportable 
         self._has_widgets = False # Update in _build_slide function
-        self._has_vars = () # Update in _build_slide function
+        self._has_vars = () # Update in _slide function for markdown slides only
         self._source = {'text': '', 'language': ''} # Should be update by Slides
         self._split_frames = True
         self._has_top_frame = True
@@ -109,8 +170,8 @@ class Slide:
 
         with suppress(Exception): # register only in slides building, not other cells
             self._app._register_postrun_cell()
-        
-        self._app._update_vars_postrun(False) # avoid while building slides to trigger other updates
+
+        self._app._auto_rebuild(None) # avoid while building slides to trigger other updates, but keep auto_rebuild state by None
         
         with self._app._set_running(self):
             with capture_content() as captured:
@@ -157,36 +218,18 @@ class Slide:
         self._reset_frames()
         self._app._update_toc()
     
-    def rebuild(self,**kwargs):
-        """Rebuild a makrdown slide to update varaiables form kwargs and notebook scope! 
-        Variables on slide will be substituted from notebook if not in kwargs.
-        """
-        if (extras := [k for k in kwargs if not k in self._has_vars]):
-            print(f"Variables {extras} not in required variables {self.vars}")
-        self._md_vars = {k:v for k,v in kwargs.items() if k in self._has_vars} # Rest on each run, don't pile up
-        return self._rebuild(True)
-    
     def _rebuild(self, go_there=False):
-        if not self._markdown:
-            raise RuntimeError("can only rebuild slides created purely from markdown (excluding fmt)!")
+        if not self._markdown and go_there: # this avoid printing logs during bacth rebuilds
+            return print("Exception: Can only rebuild slides created purely from markdown!")
         
         with self._app.navigate_back(self.index if go_there else None):
             self._app._slide(f'{self.number} -m', self._markdown)
-            self._app._unregister_postrun_cell() # Avoid other cells having postrun after this
-            self._app._update_vars_postrun(True) # Keep updating after this
+            self._app._unregister_postrun_cell() # Avoid showing slides in this rebuild
+            self._app._auto_rebuild('ondemand') # set back to previous state as capture removes it
     
     @property
     def _req_vars(self):
-        "Only vars not set by rebuild shoul be taken from top namespace."
-        return tuple([v for v in self._has_vars if not v in self._md_vars])
-    
-    @property
-    def vars(self):
-        "Get variables names info by their enclosing scope on this slide."
-        return {
-            'by:__main__': self._req_vars, 
-            'by:Slide.rebuild': tuple(self._md_vars.keys())
-        }
+        return tuple([v for v in self._has_vars if not v in self._md_vars]) # only those not set on slide
 
     def _reset_toc(self):
         self._app._sec_id2dom() # for clickable links
@@ -510,9 +553,9 @@ class Slide:
         Each call will reset previous call if props given explicitly, otherwise not.
 
         ::: note-tip
-            - See hl`Slides.css_syntax` for information on how to write CSS dictionary.
-            - Unlike hl`slides.html('style',props)`, you can set CSS variables at top level here including theme variables
-            hl['css']` --fg[1,2,3]-color `,hl['css']` --bg[1,2,3]-color ` and hl['css']` --[accent, pointer]-color ` to tweek appearance of individual or all slides.
+            - See code`Slides.css_syntax` for information on how to write CSS dictionary.
+            - Unlike code`slides.html('style',props)`, you can set CSS variables at top level here including theme variables
+            code['css']` --fg[1,2,3]-color `,code['css']` --bg[1,2,3]-color ` and code['css']` --[accent, pointer]-color ` to tweek appearance of individual or all slides.
         """
         if this is not None:
             self._css = self._fix_css(this, this_slide=True)
@@ -574,7 +617,7 @@ class Slide:
         return styles.animations[name].replace('.SlideBox',f'.{self._app.uid} .SlideBox')
             
     def set_animation(self, this=None, main = None,frame = None):
-        "Set animation of this slide. Provide None if need to stop animation. Use main_all and frame to set animation to all slides."
+        "Set animation of this slide. Provide None if need to stop animation. Use `main` and `frame` to set animation to all slides."
         self.__class__._animations['main'] = '' if main is None else self._instance_animation(main)
         self.__class__._animations['frame'] = '' if frame is None else self._instance_animation(frame)
         self._animation = '' if this is None else self._instance_animation(this)
@@ -609,6 +652,52 @@ def _build_slide(app, slide_number):
         if content.data.get('application/vnd.jupyter.widget-view+json',{}):
             this._has_widgets = True
             break # No need to check other widgets if one exists
+        
+class SlideGroup:
+    """Proxy calls/attributes to multiple Slide instances.
 
-    if this._markdown:
-        this._has_vars = _matched_vars(this._markdown)
\ No newline at end of file
+    - Broadcasts Slide methods to all slides in group; returns None if all methods return None, else a tuple of results
+    - Non-callable attributes return a tuple of values
+    - Special attribute 'vars' returns a Vars proxy over the group
+    - Behaves like a tuple for indexing/iteration; use .values to get underlying slides
+    """
+    def __init__(self, slides):
+        self._slides = tuple(slides)
+
+    def __repr__(self):
+        ids = ','.join(str(s.number) for s in self._slides)
+        return f"SlideGroup([{ids}])"
+
+    def __len__(self): return len(self._slides)
+    def __iter__(self): return iter(self._slides)
+    def __contains__(self, item): return item in self._slides
+    
+    @property
+    def values(self): 
+        "Returns underlying Slide instances as a tuple."
+        return self._slides
+
+    def __getitem__(self, key):
+        if isinstance(key, slice):
+            return SlideGroup(self._slides[key])
+        return self._slides[key]
+
+    def __dir__(self):
+        # expose public Slide attributes for completion
+        slide_attrs = [n for n in dir(Slide) if not n.startswith('_')]
+        return sorted(set(slide_attrs + ['vars', 'values'] + list(self.__dict__.keys())))
+
+    def __getattr__(self, name: str):
+        # Broadcast method or collect attribute across slides
+        attr = getattr(Slide, name, None)
+        if callable(attr):
+            @wraps(attr)
+            def _call(*args, **kwargs):
+                results = tuple(getattr(s, name)(*args, **kwargs) for s in self._slides)
+                return None if all(r is None for r in results) else results
+            
+            _call.__doc__ = f"Broadcast Slide.{name} to all slides in this group.\n" + (attr.__doc__ or '')
+            return _call
+        elif name == 'vars':
+            return Vars(*self._slides)
+        return tuple(getattr(s, name) for s in self._slides)
