@@ -323,7 +323,12 @@ def style_css(colors, fonts, layout, _root = False):
             ':is(ul,ol)': {
                 'margin-block': '0.2em !important' # avoid extra space, just add as much as column gap
             },
-            'dl': {'display': 'grid','margin-block':'0.5em'}, # Jupyterlab fix
+            'dl': {
+                'display': 'grid',
+                'margin-block':'0.5em',
+                'font-family':'var(--jp-content-font-family) !important',
+                'font-size':'var(--text-size) !important', # somwhow gets different font size
+            }, # Jupyterlab fix
             'dl > dt': {
                 'color': 'var(--fg3-color)',
                 'font-weight': 'bold', 
@@ -449,7 +454,7 @@ def style_css(colors, fonts, layout, _root = False):
                 'column-gap':'0.2em',
                 'height':'auto',
                 'box-sizing':'border-box !important',
-                '> *': {'box-sizing':'border-box !important',},
+                '> *': {'box-sizing':'border-box !important','min-width':'0 !important',}, # avoid overflow due to stubborn elements
                 'table': {'width':'calc(100% - 0.5em)'}, # make table full width inside columns with some padding
             },
         },
@@ -492,25 +497,14 @@ def style_css(colors, fonts, layout, _root = False):
                 'background':'none !important', # This should be none as will given by the code_css 
             },
             'code': {
-                'counter-increment':'line',
                 'display':'inline-block !important', # should be on new line 
                 'width':'auto',
                 'background':'transparent !important',
                 'white-space':'pre !important',
                 'overflow-wrap':'normal !important',
                 'box-sizing':'border-box !important',
-                '^:before': {
-                    'content':'counter(line,decimal)',
-                    'position':'sticky',
-                    'top':'initial',
-                    'left':'-1px',
-                    'padding':'0 8px',
-                    'display':'inline-block', # should be inline 
-                    'text-align':'right',
-                    '-webkit-user-select':'none',
-                    'margin-right':'8px',
-                    'font-size':'80% !important',
-                    'text-shadow': '0 1px var(--bg1-color)',
+                '^:hover, ^:hover::before': {
+                    'background': 'var(--bg3-color)',
                 },
                 '> span': {
                     'text-shadow': '0 1px var(--bg1-color)',
@@ -521,6 +515,22 @@ def style_css(colors, fonts, layout, _root = False):
                 '^.code-no-focus': {'opacity':'0.3 !important'},
             },
         },
+        '.highlight.numbered code': {
+            'counter-increment':'line',
+            '^:before': {
+                'content':'counter(line,decimal)',
+                'position':'sticky',
+                'top':'initial',
+                'left':'-1px',
+                'padding':'0 8px',
+                'display':'inline-block', # should be inline 
+                'text-align':'right',
+                '-webkit-user-select':'none',
+                'margin-right':'8px',
+                'font-size':'80% !important',
+                'text-shadow': '0 1px var(--bg1-color)',
+            },  
+        },
         '.highlight, pre, .raw-text': {
             '^:hover::-webkit-scrollbar-thumb': {
                 'background':'#8988 !important'
@@ -542,21 +552,22 @@ def style_css(colors, fonts, layout, _root = False):
             'margin-block':'0.5px !important', # Two adjacant prints should look closer 
         },
         '.align-center:not(.columns), .align-center > *:not(.columns)': {
-            'display':'table !important',
-            'margin':'0 auto !important',
-            'width':'auto !important', # max-content creates oveflow, do not use it 
+            '^, .jp-OutputArea-output > *': {
+                'margin-left':'auto !important', 
+                'margin-right':'auto !important', 
+            },
+            'width':'auto', # don't make it important
+            '^, p': {'text-align':'center !important'},
         },
         '.align-left:not(.columns)': { 
-            'margin-right':'auto !important', 
-            'text-align':'left !important',
+            '^, .jp-OutputArea-output > *': {'margin-right':'auto !important'}, 
+            '^, p': {'text-align':'left !important'},
         },
         '.align-right:not(.columns)': { 
-            'margin-left':'auto !important', 
-            'text-align':'right !important',
+            '^, .jp-OutputArea-output > *': {'margin-left':'auto !important'}, 
+            '^, p': {'text-align':'right !important'},
         },
         '.align-right:not(.columns), .align-left:not(.columns), .align-center:not(.columns)': {
-            'display':'table !important',
-            'width':'auto !important',
             '> *:last-child': {'margin-bottom':'0.1em !important',}, 
         },
         '.rtl, .rtl > *': {
