@@ -9,9 +9,10 @@ from traitlets import observe
 import ipywidgets as ipw
 from ipywidgets import HTML, VBox, HBox, Box, Layout, Button
 from tldraw import TldrawWidget
+from dashlab import ListWidget, JupyTimer
 
 from . import styles
-from ._widgets import InteractionWidget, NotesWidget, ListWidget, JupyTimer
+from ._widgets import InteractionWidget, NotesWidget
 from .intro import get_logo, how_to_print
 from ..utils import html, htmlize
 from .. import formatters as fmtrs
@@ -134,6 +135,7 @@ class _Checks:
     notes   = ipw.Checkbox(value = False,description='Notes',layout=auto_layout) # do not observe, just keep track when slides work
     toast   = ipw.Checkbox(value = True, description='Notifications',layout=auto_layout)
     focus   = ipw.Checkbox(value = True, description='Auto Focus',layout=auto_layout)
+    rebuild = ipw.Checkbox(value = True, description='Auto Rebuild',layout=auto_layout)
     navgui  = ipw.Checkbox(value = True, description='Show Nav. GUI',layout=auto_layout)
     confirm = ipw.Checkbox(value = False, description='Overwrite Existing File',layout=auto_layout)
 
@@ -208,8 +210,8 @@ class Widgets:
                 self.sliders.width,
                 self.theme,
                 HTML('<b>Additional Features</b>',layout = _html_layout),
-                self.checks.focus, self.checks.notes,self.checks.toast,
-                self.checks.navgui, self.checks.reflow,
+                self.checks.focus, self.checks.rebuild, self.checks.notes,
+                self.checks.toast, self.checks.navgui, self.checks.reflow, 
                 HTML(html('details',[html('summary','<b>HTML File Export</b>'), how_to_print]).value,layout = _html_layout),
                 self.buttons.export,
                 self.checks.confirm,
