@@ -3,26 +3,25 @@ from contextlib import contextmanager, suppress
 from collections import namedtuple
 from collections.abc import Iterable
 from itertools import zip_longest
-from typing import Tuple, Union
+from typing import Union, overload
 from functools import wraps
 from pathlib import Path
 
 from IPython import get_ipython
 from IPython.display import display, clear_output
 
-from .xmd import fmt, parse, get_main_ns, extender as _extender
-from .source import Code
+from .xmd import xmd, esc, fmt, get_main_ns, _matched_vars
 from .writer import hold, write
 from .formatters import bokeh2html, plt2html, serializer
 from . import utils
-from . import interaction as _interac
+from . import dashlab
 
 _under_slides = {k: getattr(utils, k, None) for k in utils.__all__}
 
 from ._base.widgets import TOCWidget, ipw # patched one
 from ._base.base import BaseSlides
 from ._base.intro import how_to_slide, get_logo
-from ._base.slide import Slide, _build_slide
+from ._base.slide import Slide, SlideGroup, _build_slide
 from ._base.icons import Icon as _Icon
 from .__version__ import __version__
 
@@ -78,14 +77,14 @@ class Singleton(type):
             cls._instance = super().__call__(extensions=extensions, **settings)
             cls._instance.fsep = fsep # frame separator is needed to be attached
         else: # reset these settings on previous instance on every call
-            cls._instance.extender.extend(extensions) 
+            xmd.extensions.extend(extensions) 
             cls._instance.settings(**settings)
         return cls._instance
 
 
 class Slides(BaseSlides,metaclass=Singleton):
     """Interactive Slides in IPython Notebook. Only one instance can exist. `settings` 
-    are passed to hl`Slides.settings()` if you like to set during initialization. You
+    are passed to code`Slides.settings()` if you like to set during initialization. You
     can also edit file .ipyslides-assets/settings.json to make settings persistent across sessions
     and load/sync them via GUI in sidepanel.
     
@@ -98,22 +97,26 @@ class Slides(BaseSlides,metaclass=Singleton):
     ```
     ::: note-info
         The traitlets callables under settings returns settings back to enable chaining 
-        without extra typing, like hl`Slides.settings.logo().layout()...` .
+        without extra typing, like code`Slides.settings.logo().layout()...` .
     
     ::: note-tip
-        - Use hl`Slides.instance()` class method to keep older settings. hl`Slides()` apply default settings every time.
-        - Run hl`slides.demo()` to see a demo of some features.
-        - Run hl`slides.docs()` to see documentation.
+        - Use code`Slides.instance()` class method to keep older settings. code`Slides()` apply default settings every time.
+        - Run code`slides.demo()` to see a demo of some features.
+        - Run code`slides.docs()` to see documentation.
         - Instructions in left settings panel are always on your fingertips.
         - Creating slides in a batch using `Slides.create` is much faster than adding them one by one.
         - In JupyterLab, right click on the slides and select `Create New View for Output` for optimized display.
         - To jump to source cell and back to slides by clicking buttons, set `Windowing mode` in Notebook settings to `defer` or `none`.
-        - See hl`Slides.xmd_syntax` for extended markdown syntax, especially variables formatting.
+        - See code`Slides.xmd.syntax` for extended markdown syntax, especially variables formatting.
         - Inside python scripts or for encapsulation, use `Slides.fmt` to pick variables from local scope.
     
     ::: note-info
-        `Slides` can be indexed same way as list for sorted final indices. For indexing slides with given number, use comma as hl`Slides[number,] -> Slide` 
-        or access many via list as hl`Slides[[n1,n2,..]] -> tuple[Slide]`. Use indexing with given number to apply persistent effects such as CSS.
+        - `Slides` can be indexed same way as list for sorted final indices. 
+        - For indexing slides with given number, use comma as code`Slides[number,] → Slide` 
+        - Access many via list as code`Slides[[n1,n2,..]] → SlideGroup` or slice as code`Slides[start:stop:step] → SlideGroup`.
+        - `SlideGroup` can be used to apply batch operations on many slides at once, e.g. code`Slides[[1,3,5]].vars.update(name='Alice')` or code`Slides[2:5].set_css(...)`.
+        - Use indexing with given number to apply persistent effects such as CSS or acess via attributes such as 
+          code`Slides.s0`, code`Slides.s1` etc. for existing slides, so `Slides.s10 == Slides[10,]` if slide with number 10 exists.
     """
 
     @classmethod
@@ -130,19 +133,18 @@ class Slides(BaseSlides,metaclass=Singleton):
 
         self.get_child_dir('.ipyslides-assets', create = True) # It should be present/created to load resources     
         self.settings(**settings)
-        _extender.extend(extensions) # globally once
-
-        self.extender   = _extender
+        xmd.extensions.extend(extensions) # globally once
+ 
         self.plt2html   = plt2html
         self.bokeh2html = bokeh2html
         self.get_logo   = get_logo
-        self.code       = Code  # Code source
         self.icon       = _Icon  # Icon is useful to add many places
-        self.ei         = _interac # whole interaction module
+        self.dl         = dashlab # whole dashlab module
         self.write      = write
         self.hold       = hold  # Hold display of a function until it is captured in a column of `Slides.write`
-        self.parse      = parse  # Parse extended markdown
+        self.xmd        = xmd  # Extended markdown parser
         self.fmt        = fmt # So important for flexibility
+        self.esc        = esc # lazy escape for variables in markdown
         self.serializer = serializer  # Serialize IPython objects to HTML
 
         with suppress(Exception):  # Avoid error when using setuptools to install
@@ -159,27 +161,40 @@ class Slides(BaseSlides,metaclass=Singleton):
         self._next_number = 0  # Auto numbering of slides should be only in python scripts
         self._citations = {}  # Initialize citations dictionary
         self._slides_per_cell = [] # all buidling slides in a cell will be added while capture, and removed with post run cell
-        self._md_vars = {} # will be handled by a post run cell
+        self._last_vars = {} # will be handled by a post run cell
 
         self._set_saved_citations() # from previous session
         self.wprogress = self.widgets.sliders.progress
         self.wprogress.observe(self._update_content, names=["value"])
         self.widgets.buttons.refresh.on_click(self._force_update)
         self.widgets.buttons.source.on_click(self._jump_to_source_cell)
+        self.widgets.checks.rebuild.observe(self._auto_rebuild, names=['value'])
 
         # All Box of Slides
         self._box = self.widgets.mainbox.add_class(self.uid)
         self._setup()  # Load some initial data and fixing
-        self._update_vars_postrun(True)
-
+        
         # setup toc widget after all attributes are set
         self._toc_widget = TOCWidget(self)
-        
-
+    
     def __setattr__(self, name: str, value): # Don't raise error
         if not name.startswith('_') and hasattr(self, name):
             raise AttributeError(f"Can't reset attribute {name!r} on {self!r}")
         self.__dict__[name] = value
+    
+    def __getattr__(self, name: str) -> Slide:
+        if name.startswith('s') and name[1:].isdigit(): # s0, s1, s2...
+            number = int(name[1:])
+            if number in self._slides_dict:
+                return self._slides_dict[number]
+            raise KeyError(f"Slide with number {number} was never created or may be deleted!")
+        else:
+            return super().__getattr__(name)
+    
+    def __dir__(self):
+        # To show s0, s1, s2... for existing slides in auto-completion
+        slide_attrs = [f's{k}' for k in self._slides_dict]
+        return sorted(super().__dir__() + slide_attrs)
         
     @contextmanager
     def _set_running(self, slide):
@@ -212,31 +227,41 @@ class Slides(BaseSlides,metaclass=Singleton):
             self._slides_per_cell.extend(spc) # was cleared above in unregister
             self._register_postrun_cell() # should be back
     
-    def _update_vars_postrun(self, b = False):
+    @property
+    def _nb_vars(self): # variables from notebook scope, not set by build/rebuild
+        # Keep this as property, as any pop out from rebuild will be picked at latest
+        keys = [k for s in self.markdown_slides for k in s._req_vars] # All markdown slides vars names
+        user_ns = get_main_ns() # works both in top running module and notebook
+        return {k: user_ns[k] for k in keys if k in user_ns} # avoid undefined variables
+    
+    def _auto_rebuild(self, change):
+        # Enable/Disable automatic rebuilding of markdown slides after each cell execution to update variables.
         with suppress(Exception): # Remove previous on each if exits
             self.shell.events.unregister("post_run_cell", self._md_post_run_cell)
-        if b:
+            self.notify('x') # to remove previous toast if any
+            
+        # None is used to keep previous state but remove handler in slide capture
+        if change is not None and self.widgets.checks.rebuild.value: # don't employ change, we need to call it independently
             self.shell.events.register("post_run_cell", self._md_post_run_cell)
+            if change != 'ondemand': # only when user checked toggle
+                self.notify("Auto rebuild of markdown slides is enabled for notebook-level variables update!", 10)
     
     def _md_post_run_cell(self, result):
         if result.error_before_exec or result.error_in_exec:
             return  # Do not proceed for side effects
         
-        keys = (k for s in self.all_slides for k in s._req_vars) # All slides vars names
-        user_ns = get_main_ns() # works both in top running module and notebook
-        new_vars = dict((key, user_ns.get(key)) for key in keys if key in user_ns)
-        diff = {key:value for key, value in new_vars.items() if not (key in self._md_vars)} # diff operator ^ can only work for hashable types
-        diff.update({key:value for key, value in new_vars.items() if value != self._md_vars.get(key,None)}) 
-        
+        new_vars = self._nb_vars # latest
+        diff = {key:value for key, value in new_vars.items() if not (key in self._last_vars)} # diff operator ^ can only work for hashable types
+        diff.update({key:value for key, value in new_vars.items() if value != self._last_vars.get(key,None)}) 
         if diff:
-            self._md_vars.update(new_vars) # sync from latest
+            self._last_vars.update(new_vars) # update to compare next time
             with self.navigate_back():
-                for slide in self.all_slides: 
+                for slide in self.markdown_slides: 
                     if diff.keys() & slide._req_vars: # Intersection of keys
                         slide._rebuild(True)
     
     def _post_run_cell(self, result):
-        self._update_vars_postrun(True) # This allows avoiding update from building slides
+        self._auto_rebuild('ondemand') # keep auto_rebuild state, but register if needed
         with suppress(Exception):
             self.shell.events.unregister("post_run_cell", self._post_run_cell) # it will be initialized from next building slides
         if result.error_before_exec or result.error_in_exec:
@@ -270,12 +295,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         else:
             toast = 'No source cell found!'
         
-        vars_info = [(v ,scope.split(':')[1]) for scope, value in self._current.vars.items() for v in value]
-
-        if vars_info:
-            vars_info = '<table style="width:100%;"><tr><th>Variable</th><th>Scope</th></tr>' + ''.join(
-                [f'<tr><td>{utils.hl(v)}</td><td>{utils.hl(s)}</td></tr>' for v, s in vars_info]) + '</table>'
-        
+        vars_info = utils.code(repr(self._current.vars)).inline.value if self._current._has_vars else ""
         self.notify(toast + (vars_info or ""), 10 if vars_info else 2) #  seconds to show message
 
     def _setup(self):
@@ -295,12 +315,22 @@ class Slides(BaseSlides,metaclass=Singleton):
     def __contains__(self, key): 
         return key in self._slides_dict
     
-    def __getitem__(self, key) -> Union[Slide, Tuple[Slide]]:
+    # Auto-completion after indexing like Slides[2].<Tab> exposes attributes of Slide
+    @overload
+    def __getitem__(self, key: int) -> Slide: ...
+    @overload
+    def __getitem__(self, key: tuple[int]) -> Slide: ...
+    @overload
+    def __getitem__(self, key: list[int]) -> SlideGroup: ...
+    @overload
+    def __getitem__(self, key: slice) -> SlideGroup: ...
+    
+    def __getitem__(self, key) -> Union[Slide, SlideGroup]:
         "Get slide by index or slice of computed index. Use [number,] or [[n1,n2,..]] to access slides by number they were created with."
         if isinstance(key, int):
             return self._iterable[key]
         elif isinstance(key, slice):
-            return self._iterable[key.start : key.stop : key.step]
+            return SlideGroup(self._iterable[key.start : key.stop : key.step])
         elif isinstance(key, tuple): # as [1,] or [(1,)]
             if len(key) != 1:
                 raise ValueError(f"Wrong indexing {key} found, use [number,] to access single slide by given number, or [[n1,n2,...]] for many slides!")
@@ -316,11 +346,11 @@ class Slides(BaseSlides,metaclass=Singleton):
                 else:
                     raise KeyError(f"Slide with number {k} was never created or may be deleted!")
             
-            return tuple(items)
+            return SlideGroup(items)
 
         raise KeyError(
             f"A slide could be accessed by index or slice, got {type(key)},\n"
-            "Use `Slides[number,] -> Slide` or `Slides[[n1, n2,..]] -> tuple[Slide]` to access slides by number they were created with."
+            "Use `Slides[number,] → Slide` or `Slides[[n1, n2,..]] → tuple[Slide]` to access slides by number they were created with."
         )
     
     def __del__(self):
@@ -447,7 +477,7 @@ class Slides(BaseSlides,metaclass=Singleton):
     
     def _set_ctns(self, d):
         # Here other formatting does not work for citations
-        new_citations = {k: self.parse(v, returns = True) for k, v in d.items()}
+        new_citations = {k: self.xmd(v, returns = True) for k, v in d.items()}
         added = set(new_citations) - set(self._citations)
         removed = set(self._citations) - set(new_citations)
         changed = {k for k in (set(new_citations) & set(self._citations)) if self._citations[k] != new_citations[k]}
@@ -472,7 +502,7 @@ class Slides(BaseSlides,metaclass=Singleton):
     def set_citations(self, data, mode='footnote'):
         r"""Set citations from dictionary or string with content like `\@key: citation value` on their own lines, 
         key should be cited in markdown as cite\`key\` / \@key, optionally comma separated keys.
-        `mode` for citations should be one of ['inline', 'footnote']. Number of columns in citations are determined by hl`Slides.settings.layout(..., ncol_refs=N)`.
+        `mode` for citations should be one of ['inline', 'footnote']. Number of columns in citations are determined by code`Slides.settings.layout(..., ncol_refs=N)`.
 
         ```python
         set_citations({"key1":"value1","key2":"value2"})
@@ -528,19 +558,14 @@ class Slides(BaseSlides,metaclass=Singleton):
                 self._set_ctns(json.loads(path.read_text()))
             
     @property
-    def cited_slides(self):
-        "Return slides which have citations. See also `all_slides`, `markdown_slides`."
-        return tuple([s for s in self._iterable if s._citations])
+    def cited_slides(self) -> SlideGroup:
+        "SlideGroup of all slides which have citations. See also `markdown_slides`."
+        return SlideGroup([s for s in self._iterable if s._citations])
     
     @property
-    def markdown_slides(self):
-        "Return all slides built from markdown. See also `all_slides`, `cited_slides`."
-        return tuple([s for s in self._iterable if s._markdown])
-    
-    @property
-    def all_slides(self):
-        "Return all slides. Another way is using `Slides[:]` but that loses auto completion on each slide. See also `cited_slides`, `markdown_slides`."
-        return self._iterable
+    def markdown_slides(self) -> SlideGroup:
+        "SlideGroup of all slides built from markdown. See also `cited_slides`."
+        return SlideGroup([s for s in self._iterable if s._markdown])
 
     def section(self, text):
         """Add section key to presentation that will appear in table of contents. In markdown, use section`content` syntax.
@@ -550,7 +575,7 @@ class Slides(BaseSlides,metaclass=Singleton):
 
         self.this._section = text  # assign before updating toc
         
-        for s in self.all_slides:
+        for s in self[:]:
             if s._toc_args and s != self.this: 
                 s.update_display(go_there=False)
  
@@ -559,6 +584,15 @@ class Slides(BaseSlides,metaclass=Singleton):
         self.verify_running("toc can only be added under slides constructor!")
         self.this._toc_args = (title, highlight)
         display(self.this._reset_toc()) # Must to have metadata there
+    
+    def refs(self, ncol=2):
+        r"Displays references when in footnote mode. refs are set in `Slides.set_citations`. In markdown, use refs\`ncol\` syntax."
+        self.verify_running("refs can only be added under slides constructor!")
+        self.this._set_refs = False # already added here
+        if self._cite_mode == "footnote":
+            _cits = ''.join(v.value for v in sorted(self.this._citations.values(), key=lambda x: x._id))
+            return self.html("div", _cits, css_class = 'Citations text-small', 
+                style = f'column-count: {ncol} !important;')
 
     def link(self, label, back_label=None, icon=None, back_icon=None):
         r"""Create a link to jump to another slide. Use `label` for link text 
@@ -567,7 +601,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         - Use `link.origin` to create a link to jump to target slide where `link.target` is placed.
         - If back_label was provided, `link.target` will be able to jump back to the `link.origin`.
         - In makdown, you can use created link as variables like `\%{link.origin}` and `\%{link.target}` to display links.
-        - Use similar links in markdown as \`<link:[unique id here]:origin label>\` and \`<link:[unique id here same as origin]:target [back_label,optional]>\`.
+        - Use similar links in markdown as `<link:[unique id here]:origin label>` and `<link:[unique id here same as origin]:target [back_label,optional]>`.
         - In markdown, icons can be passed in label as alert`"fa\`arrow\` label text"`.
         """
         anchor_id = uuid.uuid4().hex  # Generate unique anchor id
@@ -598,7 +632,7 @@ class Slides(BaseSlides,metaclass=Singleton):
 
         clear_output(wait = True) # Avoids jump buttons and other things in same cell created by scripts producing slides
         self._unregister_postrun_cell() # no need to scroll button where showing itself
-        self._update_vars_postrun(True)
+        self._auto_rebuild('ondemand') # keep auto_rebuild state, but register if needed
         self._force_update()  # Update before displaying app, some contents get lost
         self.settings._update_theme() # force it, sometimes Inherit theme don't update
         with self._loading_splash(None, self.get_logo('48px', 'IPySlides')): # need this to avoid color flicker in start
@@ -706,7 +740,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         return self._next_number # for python file as well as first run of cell in notebook
 
     # defining magics and context managers
-    def _slide(self, line, cell, fmt_kws={}, synced=False): # fmt_kws for markdown variables substitution
+    def _slide(self, line, cell):
         """Capture content of a cell as `slide`.
             ---------------- Cell ----------------
             %%slide 1
@@ -717,12 +751,13 @@ class Slides(BaseSlides,metaclass=Singleton):
             %%slide 2 -m
             Everything here and below is treated as markdown, not python code.
             ::: note-info
-                Find special syntax to be used in markdown by `Slides.xmd_syntax`.
+                Find special syntax to be used in markdown by `Slides.xmd.syntax`.
         ::: note
             - If Markdown is separated by two dashes (--) on it's own line, multiple frames are created and shown incrementally.
             - In case of frames, you can add %++ (percent plus plus) in the content to add frames incrementally.
             - Frames separator (--) just after `multicol` creates incremental columns.
             - Use `%%slide -1` to enable auto slide numbering. Other cell code is preserved.
+            - 
 
         """
         line = line.strip().split()  # VSCode bug to inclue \r in line
@@ -747,20 +782,18 @@ class Slides(BaseSlides,metaclass=Singleton):
             with _build_slide(self, slide_number) as s:
                 prames = re.split(r"^\s*--\s*$", s._markdown, flags=re.DOTALL | re.MULTILINE)   
                 # Update source beofore parsing content to make it available for variable testing
-                s._set_source(
-                    str(fmt(cell,**fmt_kws)) if fmt_kws else cell, # nice str repr of fmt
-                    "python" if fmt_kws else "markdown"
-                )  
-
+                s._set_source(cell, "markdown") # set source before running to have it available for user
+                vars = _matched_vars(cell) # update has_vars before running to have ready for auto rebuild
+                stored = {**esc._store, **s._esc_vars} # keep previous stored variables, first time come only from esc._store
+                s._has_vars = tuple([v for v in vars if v not in stored]) # esc is encapsulated by design
+                s._esc_vars = {v: stored[v] for v in vars if v in stored} # store for rebuilds internally
+                
                 for idx, (frm, prm) in enumerate(zip_longest(frames, prames, fillvalue='')):
                     if '%++' in frm: # remove %++ from here, but stays in source above for user reference
                         frm = frm.replace('%++','').strip() # remove that empty line too
                         s.stack_frames(True)
                     
-                    if fmt_kws:
-                        fmt(frm, **fmt_kws).parse(returns = False) # enclosed scope set by user
-                    else:
-                        parse(frm, returns = False) # left for notebook to handle
+                    self.xmd(frm, returns = False) # parse and display content
                     
                     if len(frames) > 1:
                         self.fsep() # should not be before, needs at least one thing there
@@ -786,9 +819,9 @@ class Slides(BaseSlides,metaclass=Singleton):
         if no other formatting specified.
         Inline columns are supported with stack`C1 || C2` syntax."""
         if cell is None:
-            return parse(line, returns = False)
+            return xmd(line, returns = False)
         else:
-            return parse(cell, returns = False)
+            return xmd(cell, returns = False)
 
     @contextmanager
     def _loading_splash(self, btn, extra = None):
@@ -811,7 +844,7 @@ class Slides(BaseSlides,metaclass=Singleton):
 
     def _force_update(self, btn=None):
         with self._loading_splash(btn or self.widgets.buttons.refresh):
-            for slide in self.all_slides:
+            for slide in self[:]:  # Update all slides
                 if slide._has_widgets or (slide is self._current): # Update current even if not has_widgets, fixes plotlty etc
                     slide.update_display(go_there=False)
             
@@ -892,7 +925,7 @@ class fsep:
     - Use `fsep()` to split code into frames. In markdown slides, use two dashes --.
     - Use `fsep.iter(iterable)` to split after each item in iterable automatically.
     - Setting `stack=True` in `fsep` or `fsep.iter` once under a slide to show frames incrementally. 
-        In markdown slides, use %++. The last called value of `stack` overrides any previous value.
+        In markdown slides, use %++. The last called value of stack overrides any previous value.
     - Content before first frame separator is added on all frames. This helps adding same title once.
     """
     _app_ins = Slides.instance # need to be called as it would not be defined initially
@@ -921,4 +954,4 @@ class fsep:
         for item in iterable:
             cls(stack) # put one separator before
             yield item
-        cls(stack) # put after all done to keep block separated
\ No newline at end of file
+        cls(stack) # put after all done to keep block separated
