@@ -16,6 +16,7 @@ from IPython.display import display, HTML, Audio, Video, Image as IPyImage
 from IPython.display import __dict__ as _all
 from IPython.utils.capture import RichOutput, capture_output
 from IPython import get_ipython
+from dashlab.utils import _inline_style
 
 __reprs = [rep.replace('display_','') for rep in _all if rep.startswith('display_')] # Can display these in write command
 
@@ -75,8 +76,9 @@ class _Output(ipw.Output):
 
 
 class XTML(HTML):
+    "This HTML will be diplayable, printable and formatable. Use `self.as_widget()` to get a widget with same content."
     def __init__(self, *args,**kwargs):
-        "This HTML will be diplayable, printable and formatable. Use `self.as_widget()` to get a widget with same content."
+        "Initialize with HTML string or other arguments that can be passed to `IPython.display.HTML` class."
         super().__init__(*args,**kwargs)
         
     def __format__(self, spec):
@@ -104,7 +106,9 @@ class XTML(HTML):
     def as_widget(self):
         "Returns ipywidgets.HTML with same data."
         return ipw.HTML(self.value)
-        
+
+def _fig_caption(text): # need here to use in many modules
+    return f'<figcaption class="no-zoom">{htmlize(text)}</figcaption>' if text else ''
 
 def plt2html(plt_fig = None,transparent=True,width = None, caption=None, crop=None):
     """Write matplotib figure as HTML string to use in `ipyslide.utils.write`.
@@ -123,8 +127,7 @@ def plt2html(plt_fig = None,transparent=True,width = None, caption=None, crop=No
     _fig = plt_fig or plt.gcf()
     plot_bytes = BytesIO()
     _fig.savefig(plot_bytes,format='svg',transparent = transparent)
-    _fig.clf() # Clear image to avoid other display
-    plt.close() #AVoids throwing text outside figure
+    plt.close(_fig) #AVoids throwing text outside figure
     if width is None:
         width = f'{_fig.get_size_inches()[0]}in'
     width = (f'width:{width}px' if isinstance(width,int) else f'width:{width}') + ';max-width:100%;' # important to avoid overflow
@@ -136,8 +139,7 @@ def plt2html(plt_fig = None,transparent=True,width = None, caption=None, crop=No
     
     cap = ''
     if caption:
-        from .xmd import _fig_caption # avoid circular import and only on demenad
-        cap = _fig_caption(caption)
+        cap = _fig_caption(caption) # Caption is optional, but if given, it should be there
 
     return XTML(f"<figure class='zoom-child mpl'>{svg + cap}</figure>")
 
@@ -199,6 +201,8 @@ def code_css(style='default',color = None, background = None, hover_color = 'var
     """Style code block with given style from pygments module. ` color ` and ` background ` are optional and will be overriden if pygments style provides them.
     """
     _class = '.highlight' if css_class is None else f'.highlight.{css_class}'
+    if lineno:
+        _class += '.numbered'
     
     if style not in pygments.styles.get_all_styles():
         raise KeyError(f"Style {style!r} not found in {list(pygments.styles.get_all_styles())}")
@@ -261,25 +265,14 @@ def _highlight(code, language='python', name = None, css_class = None, style='de
     code_ = '\n' + '\n'.join([f'<code>{line}</code>' for line in lines]) # start with newline is important
     _title = '' if name is False else name if name else language.title()
     
-    if isinstance(css_class, str):
-        start = start.replace('class="highlight"',f'class="highlight {css_class}"')
+    _class = (css_class if isinstance(css_class, str) else '') + (' numbered' if lineno else '')
+    start = start.replace('class="highlight"',f'class="highlight {_class}"')
     
     return f'''<div><span class="lang-name">{_title}</span>
         <div class="highlight-wrapper" style="height:auto;max-height:{height};overflow:auto;position:relative;">
         {_style}\n{start}
         <pre>{code_}
         </pre>\n{end}</div></div>'''
-
-def _inline_style(kws_or_widget):
-    "CSS inline style from keyword arguments having _ inplace of -. Handles widgets layout keys automatically."
-    if isinstance(kws_or_widget, ipw.DOMWidget):
-        kws = {k:v for k,v in kws_or_widget.layout.get_state().items() if v and (k[0]!='_')}
-    elif isinstance(kws_or_widget, dict):
-        kws = kws_or_widget
-    else:
-        raise TypeError("expects dict or ipywidgets.Layout!")
-    out = ''.join(f"{k.replace('_','-')}:{v};" for k,v in kws.items())
-    return f'style="{out}"'
     
 class Serializer:
     def __init__(self):
@@ -304,12 +297,12 @@ class Serializer:
         
         slides = ipyslides.Slides()
         @slides.serializer.register(MyObject)
-        def parse_myobject(obj):
+        def make_h1(obj):
             return f'<h1>{obj!r}</h1>'
             
         my_object = MyObject()
         slides.write(my_object) #This will write "My object is awesome" as main heading
-        parse_myobject(my_object) #This will return "<h1>My object is awesome</h1>"
+        make_h1(my_object) #This will return "<h1>My object is awesome</h1>"
         
         #This is equivalent to above for custom objects(builtin objects can't be modified)
         class MyObject:
@@ -321,7 +314,7 @@ class Serializer:
         ```
         ::: note
             - Serializer function should return html string. It is not validated for correct code on registration time.       
-            - Serializer is useful for buitin types mostly, for custom objects, you can always define a `_repr_html_` method which works as expected.
+            - Serializer is useful for buitin types mostly, for custom objects, you can always define a ` _repr_html_ ` method which works as expected.
             - Serialzers for widgets are equivalent to `Slides.alt(func, widget)` inside `write` command for export purpose. Other commands such as `Slides.[cols,rows,...]` will pick oldest value only.
             - IPython's `display` function automatically take care of serialized objects.
         """
@@ -411,10 +404,7 @@ class Serializer:
         if isinstance(box_widget,ipw.HBox):
             kwargs.update(dict(display="flex",flex_flow="row nowrap"))
         elif isinstance(box_widget,ipw.VBox):
-            if 'ips-interact' in box_widget._dom_classes:
-                kwargs.update(dict(display='grid'))
-            else:
-                kwargs.update(dict(display="flex",flex_flow="column nowrap"))
+            kwargs.update(dict(display="flex",flex_flow="column nowrap"))
         
         kwargs.update({k:v for k,v in box_widget.layout.get_state().items() if v and k[0]!='_'}) # only those if not None
         css_class = ' '.join(box_widget._dom_classes) # To keep style of HTML widget, latest as well
@@ -609,8 +599,8 @@ def htmlize(obj):
         return error("TypeError","Received a non-serializable object. Use display or write directly or use %{obj:nb} syntax in markdown!").value
     
     if isinstance(obj,str):
-        from .xmd import parse # Avoid circular import
-        return parse(obj, returns = True)
+        from .xmd import xmd # Avoid circular import
+        return xmd(obj, returns = True) 
     elif isinstance(obj,XTML) or callable(getattr(obj, '_repr_html_',None)):
         return obj._repr_html_() #_repr_html_ is a method of XTML and it is quick   
     else:
