@@ -1,11 +1,10 @@
-_attrs = ['AnimationSlider', 'JupyTimer', 'ListWidget', 'alt', 'alert', 'as_html', 'as_html_widget', 'block', 'bullets', 'color', 'error', 'table', 'suppress_output','suppress_stdout','capture_content',
-    'details', 'set_dir', 'textbox', 'highlight', 'hl', 'hspace', 'vspace', 'center', 'image', 'svg','iframe','frozen', 'raw', 
+_attrs = ['AnimationSlider', 'JupyTimer', 'ListWidget', 'alt', 'alert', 'as_html', 'as_html_widget', 'bullets', 'color', 'error', 'table', 'suppress_output','suppress_stdout','capture_content',
+    'details', 'set_dir', 'textbox', 'code', 'hspace', 'vspace', 'center', 'image', 'svg','iframe','frozen', 'raw', 
     'zoomable','html', 'sig','stack', 'styled', 'doc','today','get_child_dir','get_notebook_dir','is_jupyter_session','inside_jupyter_notebook']
 
-_attrs.extend([f'block_{c}' for c in 'red green blue cyan magenta yellow'.split()])
 __all__ = sorted(_attrs)
 
-import os, re, json
+import os, re, json, textwrap
 import datetime
 import inspect
 import traceback
@@ -20,12 +19,12 @@ from PIL import Image as pilImage, ImageGrab
 from IPython import get_ipython
 from IPython.display import SVG, IFrame
 from IPython.display import Image, display
+from dashlab.widgets import AnimationSlider, JupyTimer, ListWidget # For export
+from dashlab.utils import _build_css # This is very light weight and too important dependency
 
-from ._base._widgets import AnimationSlider, JupyTimer, ListWidget # For export
-from .formatters import ipw, XTML, IMG, frozen, get_slides_instance, htmlize, _inline_style
-from .xmd import _fig_caption, get_unique_css_class, capture_content, parse, raw, error # raw error for export from here
-from .writer import Writer, _Output
-from .source import highlight
+from .formatters import ipw, XTML, IMG, frozen, get_slides_instance, _inline_style, htmlize, _fig_caption
+from .xmd import get_unique_css_class, capture_content, raw, error 
+from .source import code
 
 def is_jupyter_session():
      "Return True if code is executed inside jupyter session even while being imported."
@@ -65,18 +64,6 @@ def get_clips_dir():
     "Returns directory where clips are saved."
     return get_child_dir(".ipyslides-assets", "clips", create = True)
 
-def hl(obj, language="python"): # No need to have in __all__, just for markdown
-    "Highlight code object in inline mode. `language` is the language name, default is python."
-    try: 
-        return XTML( 
-            '<br>'.join('<code class="highlight inline" style="white-space:pre;">' + c 
-                for c in re.findall(r'\<\s*code.*?\>(.*?\<\s*\/\s*code\s*\>)', 
-                    highlight(obj, language=language).value, 
-                    flags=re.DOTALL | re.MULTILINE
-        ))) # intended to be one liner, but leave for flexibility
-    except:
-        return html('code',str(obj)) # Fallback , no need to raise errors
-
 _example_props = {
     '.A': { # .A is repeated nowhere! But in CSS it is a lot
         'z-index': '2',
@@ -152,63 +139,6 @@ def set_dir(path):
     finally:
         os.chdir(current)
 
-def _validate_key(key):
-    "Validate key for CSS,allow only string or tuple of strings. commas are allowed only in :is(.A,#B),:has(.A,#B) etc."
-    if not isinstance(key,str):
-        raise TypeError(f'key should be string, got {key!r}')
-
-    if ',' in key:
-        all_matches = re.findall(r'\((.*?)\)',key,flags=re.DOTALL)
-        for match in all_matches:
-            key = key.replace(f'{match}',match.replace(',','$'),1)  # Make safe from splitting with comma
-    return key
-
-def _build_css(selector, data):
-    "selector is tuple of string(s), data contains nested dictionaries of selectors, attributes etc."
-    content = '\n' # Start with new line so style tag is above it
-    children = []
-    attributes = []
-    
-    for key, value in data.items():
-        key = _validate_key(key) # Just validate key
-        if isinstance(value, dict):
-            children.append( (key, value) )
-        elif isinstance(value, (list, tuple)): # Fallbacks
-            for item in value:
-                attributes.append( (key, item) )
-        else: # str, int, float etc. No need to check. User is responsible for it
-            attributes.append( (key, value) )
-    if attributes:
-        content += re.sub(r'\s+\^','', (' '.join(selector) + " {\n").lstrip()) # Join nested tags to parent if it starts with ^
-        content += '\n'.join(f"\t{key.replace('_','-')} : {value};"  for key, value in attributes)  # _ allows to write dict(key=value) in python, but not in CSS props
-        content += "\n}\n"
-
-    for key, value in children:
-        if key.startswith('<'): # Make it root level
-            content += _build_css((key.lstrip('<'),), value)
-        elif key.startswith('@media') or key.startswith('@container'): # Media query can be inside a selector and will go outside
-            content += f"{key} {{\n\t"
-            content += _build_css(selector, value).replace('\n','\n\t').rstrip('\t') # last tab is bad
-            content += "}\n"
-        elif key.startswith('@'): # Page, @keyframes etc.
-            content += f"{key} {{\n\t"
-            content += _build_css((), value).replace('\n','\n\t').rstrip('\t')
-            content += "}\n"
-        elif  key.startswith(':root'): # This is fine
-            content+= _build_css((key,), value)
-        else:
-            old_sels = re.sub(r'\s+', ' ',' '.join(selector)).replace('\n','').split(',') # clean up whitespace
-            sels = ',\n'.join([f"{s} {k}".strip() for s in old_sels for k in key.split(',')]) # Handles all kind of nested selectors
-            content += _build_css((sels,), value)
-
-    
-    content = re.sub(r'\$', ',', content) # Replace $ with ,
-    content = re.sub(r'\n\s+\n|\n\n','\n', content) # Remove empty lines after tab is replaced above
-    content = re.sub(r'\t', '    ', content) # 4 space instead of tab is bettter option
-    content = re.sub(r'\^',' ', content) # Remove left over ^ from start of main selector
-        
-    return content
-
 def _styled_css(props : dict):
     if not isinstance(props, dict):
         raise TypeError("props should be a dictionay of CSS selectors and properties.")
@@ -223,23 +153,12 @@ def _styled_css(props : dict):
     props = {k:v for k,v in props.items() if (isinstance(v,dict) or k.lstrip(' ^<'))} # Remove root attrs and top level access
     return XTML(f"<style>{_build_css((f'{klass}',),props)}</style>")
 
-_dict2css = """
-CSS is formatted using a `props` nested dictionary to simplify the process. 
-There are few special rules in `props`:
-
-- All nested selectors are joined with space, so hl`'.A': {'.B': ... }` becomes hl['css']`.A .B {...}` in CSS.
-- A '^' in start of a selector joins to parent selector without space, so hl`'.A': {'^:hover': ...}` becomes hl['css']`.A:hover {...}` in CSS. You can also use hl`'.A:hover'` directly but it will restrict other nested keys to hover only.
-- A list/tuple of values for a key in dict generates CSS fallback, so hl`'.A': {'font-size': ('20px','2em')}` becomes hl['css']`.A {font-size: 20px; font-size: 2em;}` in CSS.
-
-Read about specificity of CSS selectors [here](https://developer.mozilla.org/en-US/docs/Web/CSS/Specificity).
-"""
-
-_css_docstring = parse(_dict2css + f"""                      
+_css_docstring = htmlize(textwrap.dedent(_build_css.__doc__) + f"""                      
 ```python
 props = {json.dumps(_example_props, indent=2)}
 ```
-Output of hl`html('style',props)`, hl`set_css(props)` etc. functions. Top selector would be different based on where it is called.
-""", returns=True) + highlight(_styled_css(_example_props).value, "css","CSS").value
+Output of code`html('style',props)`, code`set_css(props)` etc. functions. Top selector would be different based on where it is called.
+""") + code(_styled_css(_example_props).value, "css","CSS").value
 
 def _alt_for_widget(func, widget):
     if not isinstance(widget, ipw.DOMWidget):
@@ -282,7 +201,7 @@ def alt(exportable_data, obj):
         - `ipywidgets`'s `HTML`, `Box` and `Output` widgets and their subclasses directly give html representation if used inside `write` command.
     """
     if not any([callable(exportable_data), isinstance(exportable_data, str)]):
-        raise TypeError(f"first arguemnt of alt should be a func (func(obj) -> html str) or html str, got {type(exportable_data)}")
+        raise TypeError(f"first arguemnt of alt should be a func (func(obj) → html str) or html str, got {type(exportable_data)}")
     
     if isinstance(obj, ipw.DOMWidget) and callable(exportable_data):
         return _alt_for_widget(exportable_data, obj)
@@ -353,9 +272,9 @@ def _clipbox_children():
     ]
     return children
 
-def details(str_html,summary='Click to show content'):
+def details(obj,summary='Click to show content'):
     "Show/Hide Content in collapsed html."
-    return XTML(f"""<details style='max-height:100%;overflow:auto;'><summary>{summary}</summary>{str_html}</details>""")
+    return XTML(f"""<details style='max-height:100%;overflow:auto;'><summary>{summary}</summary>{htmlize(obj)}</details>""")
 
 def _check_pil_image(data):
     "Check if data is a PIL Image or numpy array"
@@ -403,8 +322,8 @@ def image(data=None,width='95%',caption=None, crop = None, css_props={}, **kwarg
 
     **Returns** an `IMG` object which can be exported to other formats (if possible):
 
-    - hl`IMG.to_pil()` returns hl` PIL.Image ` or None.
-    - hl`IMG.to_numpy()` returns image data as numpy array for use in plotting libraries or None.
+    - code`IMG.to_pil()` returns code` PIL.Image ` or None.
+    - code`IMG.to_numpy()` returns image data as numpy array for use in plotting libraries or None.
     """
     if crop:
         try:
@@ -517,8 +436,6 @@ def styled(obj, css_class=None, **css_props):
                 setattr(obj.layout, k, v)
         _patch_display(obj)
         return obj.add_class(klass)
-    elif isinstance(obj, (str, bytes)):
-        return XTML(f'<div class="{klass}" {_inline_style(css_props)}>{parse(obj, True)}</div>')
     else:
         return XTML(f'<div class="{klass}" {_inline_style(css_props)}>{htmlize(obj)}</div>')
     
@@ -544,10 +461,10 @@ def html(tag, children = None,css_class = None,**node_attrs):
     `tag` can be any valid html tag name. A `tag` that ends with ` / ` will be self closing e.g. ` hr/ ` will be `<hr/>`.  Empty tag gives unwrapped children.
     `children` expects:
     
-    - If None, returns node such as 'image' -> <img alt='Image'></img> and 'image/' -> <img alt='Image' />
+    - If None, returns node such as code`html('image',alt='Image')` → code['html']`<img alt='Image'></img>` and code`html('image/',alt='Image')` → code['html']`<img alt='Image' />`
     - str: A string to be added as node's text content.
     - list/tuple of [objects]: A list of objects that will be parsed and added as child nodes. Widgets are not supported.
-    - dict if tag is 'style', this will only be exported to HTML if called under slide builder, use hl`slides[number,].set_css` otherwise. See `Slides.css_syntax` to learn about requirements of styles in dict.
+    - dict if tag is 'style', this will only be exported to HTML if called under slide builder, use code`slides[number,].set_css` otherwise. See `Slides.css_syntax` to learn about requirements of styles in dict.
     
     Example:
     ```python
@@ -620,9 +537,9 @@ def line(length=5, color='var(--fg1-color)',width=1,style='solid'):
     return f"<span style='display:inline-block;border-bottom:{width}px {style} {color};width:{length}em;max-width:100%;'></span>"
 
 def textbox(text, **css_props):
-    """Formats text in a box for writing e.g. inline refrences. `css_props` are applied to box and `-` should be `_` like `font-size` -> `font_size`. 
+    """Formats text in a box for writing e.g. inline refrences. `css_props` are applied to box and ` - ` should be ` _ ` like `font-size` → `font_size`. 
     `text` is not parsed to general markdown i.e. only bold italic etc. applied, so if need markdown, parse it to html before. You can have common CSS for all textboxes using class `text-box`."""
-    css_props = {'display':'inline','white-space': 'pre', **css_props} # very important to apply text styles in order
+    css_props = {'display':'inline','white-space': 'pre-wrap', **css_props} # very important to apply text styles in order
     return XTML(f'<span class="text-box" {_inline_style(css_props)}>{text}</span>')  # markdown="span" will avoid inner parsing
 
 def alert(text):
@@ -700,47 +617,13 @@ def table(data, headers = None, widths=None):
     
     return html('div', [stack(d, sizes=widths) for d in data],css_class=klass + ' zoom-self')
 
-def _block(*objs, widths = None, suffix = ''): # suffix is for block-{suffix} class
-    if len(objs) == 0:
-        return # Nothing
-    
-    if suffix and suffix not in 'red green blue yellow cyan magenta gray'.split():
-        raise ValueError(f'Invalid suffix {suffix!r}, should be one of [red, green, blue, yellow, cyan, magenta, gray]')
-    
-    if len(objs) == 1:
-        out = _Output().add_class('block' + (f'-{suffix}' if suffix else '')) # _Output for adding cite etc.
-        with out:
-            Writer(*objs)
-        display(out, metadata = {'UPDATE', out._model_id}) # For auto refresh
-    else:
-        Writer(*objs,widths = widths).add_class('block' + (f'-{suffix}' if suffix else '')) # Displayed
-
-    
-def block(*objs, widths = None): 
-    """
-    Format a block like in LATEX beamer with `objs` in columns and immediately display it. Format rows by given an obj as list of objects.   
-    ::: block
-        - Block is automatically displayed and returns nothing.
-        - Available functions include: `block_<red,green,blue,yellow,cyan,magenta,gray>`.
-        - You can create blocks just by CSS classes in markdown as {.block}, {.block-red}, {.block-green}, etc.
-        - See documentation of `write` command for details of `objs` and `widths`.
-    """
-    return _block(*objs, widths = widths)  
-
-def block_red(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'red')
-def block_blue(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'blue')
-def block_green(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'green')
-def block_yellow(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'yellow')
-def block_cyan(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'cyan')
-def block_magenta(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'magenta')
-
 def sig(callable,prepend_str = None):
     "Returns signature of a callable. You can prepend a class/module name."
     try:
         _sig = f'<b>{callable.__name__}</b>'
         if prepend_str: 
             _sig = f'{prepend_str}.{_sig}' 
-        _sig = f'<span class="sig">{_sig}</span>' + hl(str(inspect.signature(callable))).value
+        _sig = f'<span class="sig">{_sig}</span>' + code(str(inspect.signature(callable))).inline.value
         return XTML(_sig)
     except:
         raise TypeError(f'Object {callable} is not a callable')
@@ -810,12 +693,6 @@ def today(fmt = '%b %d, %Y',fg = 'inherit'): # Should be inherit color for markd
     "Returns today's date in given format."
     return color(datetime.datetime.now().strftime(fmt),fg=fg, bg = None)
 
-def sub(text):
-    return html('sub',text,style="font-size:85%;color:inherit;")
-
-def sup(text):
-    return html('sup',text,style="font-size:85%;color:inherit;")
-
 def bullets(iterable, ordered = False,marker = None, css_class = None):
     """A powerful bullet list. `iterable` could be list of anything that you can pass to `write` command.    
     `marker` could be a unicode charcter or string, only effects unordered list.
